@@ -6,7 +6,7 @@ model = l4,
 opt = FALSE, 
 norm = FALSE,
 backsub = NULL, 
-opt.method =  rep("Nelder", 5),
+opt.method =  "LM",
 nls.method = "port",
 sig.level = 0.05, 
 crit = "ftest",
